==> core_models-0.3.9.tar.gz: core_models-0.3.9/core_models/constants.py <==
BUYER_COMPANY_TYPE = "B"
SELLER_COMPANY_TYPE = "S"
FINANCIER_COMPANY_TYPE = "F"
ALL_COMPANY_TYPE = "A"

COMPANY_TYPES = (
    (BUYER_COMPANY_TYPE, "Buyer"),
    (SELLER_COMPANY_TYPE, "Seller"),
    (FINANCIER_COMPANY_TYPE, "Financier"),
    (ALL_COMPANY_TYPE, "All"),
)

COMPANY_TYPES_MAP = {
    BUYER_COMPANY_TYPE: "Buyer",
    SELLER_COMPANY_TYPE: "Seller",
    FINANCIER_COMPANY_TYPE: "Financier",
    ALL_COMPANY_TYPE: "All",
}

DRAFT_INVOICE_STATUS = "D"
NEW_INVOICE_STATUS = "N"
BUYER_VALIDATED_INVOICE_STATUS = "BV"
VALIDATED_INVOICE_STATUS = "V"
COMPLETED_INVOICE_STATUS = "C"
CLOSED_INVOICE_STATUS = "X"
FUNDED_INVOICE_STATUS = "F"
REJECTED_INVOICE_STATUS = "R"
WITHDRAWN_INVOICE_STATUS = "W"
AMEND_INVOICE_STATUS = "A"
AWAITING_PAYMENT_INVOICE_STATUS = "AP"
OVERDUE_INVOICE_STATUS = "O"

INVOICE_STATUSES = (
    (DRAFT_INVOICE_STATUS, "Draft"),
    (NEW_INVOICE_STATUS, "New"),
    (BUYER_VALIDATED_INVOICE_STATUS, "Validated by Buyer"),
    (VALIDATED_INVOICE_STATUS, "Validated"),
    (COMPLETED_INVOICE_STATUS, "Repaid"),
    (CLOSED_INVOICE_STATUS, "Closed"),
    (FUNDED_INVOICE_STATUS, "Funded"),
    (REJECTED_INVOICE_STATUS, "Rejected"),
    (WITHDRAWN_INVOICE_STATUS, "Withdrawn"),
    (AMEND_INVOICE_STATUS, "For Amendment"),
    (AWAITING_PAYMENT_INVOICE_STATUS, "Awaiting Payment"),
    (OVERDUE_INVOICE_STATUS, "Overdue"),
)

FAILED_TXN_STATUS = "F"
SUCCESS_TXN_STATUS = "S"
PENDING_TXN_STATUS = "P"
REVERSED_TXN_STATUS = "R"
INCOMPLETE_TXN_STATUS = "I"

TXN_STATUSES = (
    (FAILED_TXN_STATUS, "Failed"),
    (SUCCESS_TXN_STATUS, "Successful"),
    (PENDING_TXN_STATUS, "Pending"),
    (REVERSED_TXN_STATUS, "Reversed"),
    (INCOMPLETE_TXN_STATUS, "Incomplete"),
)

FIXED_LIQUIFY_FEE = "F"
PERCENTAGE_LIQUIFY_FEE = "P"

LIQUIFY_FEE_TYPES = (
    (FIXED_LIQUIFY_FEE, "Fixed"),
    (FIXED_LIQUIFY_FEE, "Percentage"),
)

PENDING_CONTRACT_STATUS = "P"
ACCEPTED_CONTRACT_STATUS = "A"
MODIFY_CONTRACT_STATUS = "M"
VERIFIED_CONTRACT_STATUS = "V"
REJECTED_CONTRACT_STATUS = "R"
CONTRACT_STATUSES = (
    (PENDING_CONTRACT_STATUS, "Pending"),
    (ACCEPTED_CONTRACT_STATUS, "Accepted"),
    (MODIFY_CONTRACT_STATUS, "Modify"),
    (VERIFIED_CONTRACT_STATUS, "Verified"),
    (REJECTED_CONTRACT_STATUS, "Rejected"),
)
PHONE_CONTRACT_ACCEPTANCE = "P"
MAIL_CONTRACT_ACCEPTANCE = "M"
DASHBOARD_CONTRACT_ACCEPTANCE = "D"
CONTRACT_ACCEPTANCE_CHANNELS = (
    (PHONE_CONTRACT_ACCEPTANCE, "Phone"),
    (MAIL_CONTRACT_ACCEPTANCE, "Mail"),
    (DASHBOARD_CONTRACT_ACCEPTANCE, "Dashboard"),
)

NEW_INVOICE_NOTIF_TYPE = 'NI'
INVOICE_WITHDRAWN_NOTIF_TYPE = 'IW'
INVOICE_REPAID_NOTIF_TYPE = 'IR'
INVOICE_FUNDED_NOTIF_TYPE = 'IF'
INVOICE_AWAITING_PAYMENT_NOTIF_TYPE = 'IA'
INVOICE_VALIDATED_NOTIF_TYPE = 'IV'
INVOICE_OVERDUE_NOTIF_TYPE = 'IO'
INVOICE_REJECTED_NOTIF_TYPE = 'IX'
AMEND_INVOICE_NOTIF_TYPE = 'MI'
CONTRACT_CONFIRMED_NOTIF_TYPE = 'CC'
MODIFY_CONTRACT_NOTIF_TYPE = 'CM'
NEW_CONTRACT_NOTIF_TYPE = 'NC'
NOTIFICATION_TYPES = (
    (NEW_INVOICE_NOTIF_TYPE, 'New Invoice'),
    (INVOICE_WITHDRAWN_NOTIF_TYPE, 'Invoice Withdrawn'),
    (INVOICE_REPAID_NOTIF_TYPE, 'Invoice Repaid'),
    (INVOICE_FUNDED_NOTIF_TYPE, 'Invoice Funded'),
    (INVOICE_OVERDUE_NOTIF_TYPE, 'Invoice Overdue'),
    (AMEND_INVOICE_NOTIF_TYPE, 'Amend Invoice'),
    (INVOICE_AWAITING_PAYMENT_NOTIF_TYPE, 'Invoice Awaiting Payment'),
    (INVOICE_VALIDATED_NOTIF_TYPE, 'Invoice Validated'),
    (CONTRACT_CONFIRMED_NOTIF_TYPE, 'Contract Confirmed'),
    (MODIFY_CONTRACT_NOTIF_TYPE, 'Modify Contract'),
    (NEW_CONTRACT_NOTIF_TYPE, 'New Contract'),
)

REJECTED_PROFILE_STATUS = "R"
APPROVED_PROFILE_STATUS = "A"
PENDING_PROFILE_STATUS = "P"

PROFILE_REQUEST_STATUSES = (
    (REJECTED_PROFILE_STATUS, "Rejected"),
    (APPROVED_PROFILE_STATUS, "Approved"),
    (PENDING_PROFILE_STATUS, "Pending"),
)

INDIVIDUAL_BANK_ACCOUNT = "individual"
CORPORATE_BANK_ACCOUNT = "corporate"
BANK_ACCOUNT_TYPES = (
    (INDIVIDUAL_BANK_ACCOUNT, INDIVIDUAL_BANK_ACCOUNT.title()),
    (CORPORATE_BANK_ACCOUNT, CORPORATE_BANK_ACCOUNT.title()),
)

DEBIT_TRANSACTION = "D"
CREDIT_TRANSACTION = "C"
TRANSACTION_TYPES = (
    (DEBIT_TRANSACTION, "Debit"),
    (CREDIT_TRANSACTION, "Credit"),
)

VERTO_PAYMENT_GTW = "1"
PAYMENT_GTW = (
    (VERTO_PAYMENT_GTW, "Verto"),
)

BANK_ACCT_REJECTED_STATUS = "R"
BANK_ACCT_APPROVED_STATUS = "A"
BANK_ACCT_PROCESSING_STATUS = "P"

BANK_ACCT_STATUSES = (
    (BANK_ACCT_REJECTED_STATUS, "Rejected"),
    (BANK_ACCT_APPROVED_STATUS, "Approved"),
    (BANK_ACCT_PROCESSING_STATUS, "Processing"),
)

==> core_models-0.4.6.tar.gz: core_models-0.4.6/core_models/constants.py <==
BUYER_COMPANY_TYPE = "B"
SELLER_COMPANY_TYPE = "S"
FINANCIER_COMPANY_TYPE = "F"
ALL_COMPANY_TYPE = "A"

COMPANY_TYPES = (
    (BUYER_COMPANY_TYPE, "Buyer"),
    (SELLER_COMPANY_TYPE, "Seller"),
    (FINANCIER_COMPANY_TYPE, "Financier"),
    (ALL_COMPANY_TYPE, "All"),
)

COMPANY_TYPES_MAP = {
    BUYER_COMPANY_TYPE: "Buyer",
    SELLER_COMPANY_TYPE: "Seller",
    FINANCIER_COMPANY_TYPE: "Financier",
    ALL_COMPANY_TYPE: "All",
}

DRAFT_INVOICE_STATUS = "D"
NEW_INVOICE_STATUS = "N"
BUYER_VALIDATED_INVOICE_STATUS = "BV"
VALIDATED_INVOICE_STATUS = "V"
COMPLETED_INVOICE_STATUS = "C"
CLOSED_INVOICE_STATUS = "X"
FUNDED_INVOICE_STATUS = "F"
REJECTED_INVOICE_STATUS = "R"
WITHDRAWN_INVOICE_STATUS = "W"
AMEND_INVOICE_STATUS = "A"
AWAITING_PAYMENT_INVOICE_STATUS = "AP"
OVERDUE_INVOICE_STATUS = "O"
PO_INVOICE_ISSUANCE_STATUS = "II"
PO_SIGN_AGREEMENT_STATUS = "SA"

INVOICE_STATUSES = (
    (DRAFT_INVOICE_STATUS, "Draft"),
    (NEW_INVOICE_STATUS, "New"),
    (BUYER_VALIDATED_INVOICE_STATUS, "Validated by Buyer"),
    (VALIDATED_INVOICE_STATUS, "Validated"),
    (COMPLETED_INVOICE_STATUS, "Repaid"),
    (CLOSED_INVOICE_STATUS, "Closed"),
    (FUNDED_INVOICE_STATUS, "Funded"),
    (REJECTED_INVOICE_STATUS, "Rejected"),
    (WITHDRAWN_INVOICE_STATUS, "Withdrawn"),
    (AMEND_INVOICE_STATUS, "For Amendment"),
    (AWAITING_PAYMENT_INVOICE_STATUS, "Awaiting Payment"),
    (OVERDUE_INVOICE_STATUS, "Overdue"),
    (PO_INVOICE_ISSUANCE_STATUS, "Invoice Issuance"),
    (PO_SIGN_AGREEMENT_STATUS, "Sign Agreement"),
)

INVOICE_STATUS_MAP = {
    NEW_INVOICE_STATUS: 'Awaiting Validation',
    BUYER_VALIDATED_INVOICE_STATUS: 'Eligibility Check',
    VALIDATED_INVOICE_STATUS: "Awaiting Financing",
    COMPLETED_INVOICE_STATUS: "Repaid",
    CLOSED_INVOICE_STATUS: "Closed",
    FUNDED_INVOICE_STATUS: 'Funded',
    REJECTED_INVOICE_STATUS: "Rejected",
    WITHDRAWN_INVOICE_STATUS: "Withdrawn",
    AMEND_INVOICE_STATUS: "Amendment",
    DRAFT_INVOICE_STATUS: "Draft",
    AWAITING_PAYMENT_INVOICE_STATUS: "Awaiting Payment",
    OVERDUE_INVOICE_STATUS: "Overdue",
}

PO_STATUS_MAP = {
    NEW_INVOICE_STATUS: 'Buyer Verification',
    PO_SIGN_AGREEMENT_STATUS: 'Sign Agreements',
    AWAITING_PAYMENT_INVOICE_STATUS: "Awaiting Payment",
    FUNDED_INVOICE_STATUS: 'Funded',
    PO_INVOICE_ISSUANCE_STATUS: "Invoice Issuance",
    COMPLETED_INVOICE_STATUS: "Repaid",
    DRAFT_INVOICE_STATUS: "Draft",
    VALIDATED_INVOICE_STATUS: "Validated",
    CLOSED_INVOICE_STATUS: "Closed",
    REJECTED_INVOICE_STATUS: "Rejected",
    WITHDRAWN_INVOICE_STATUS: "Withdrawn",
    AMEND_INVOICE_STATUS: "Amendment",
}

FAILED_TXN_STATUS = "F"
SUCCESS_TXN_STATUS = "S"
PENDING_TXN_STATUS = "P"
REVERSED_TXN_STATUS = "R"
INCOMPLETE_TXN_STATUS = "I"

TXN_STATUSES = (
    (FAILED_TXN_STATUS, "Failed"),
    (SUCCESS_TXN_STATUS, "Successful"),
    (PENDING_TXN_STATUS, "Pending"),
    (REVERSED_TXN_STATUS, "Reversed"),
    (INCOMPLETE_TXN_STATUS, "Incomplete"),
)

FIXED_LIQUIFY_FEE = "F"
PERCENTAGE_LIQUIFY_FEE = "P"

LIQUIFY_FEE_TYPES = (
    (FIXED_LIQUIFY_FEE, "Fixed"),
    (FIXED_LIQUIFY_FEE, "Percentage"),
)

PENDING_CONTRACT_STATUS = "P"
ACCEPTED_CONTRACT_STATUS = "A"
MODIFY_CONTRACT_STATUS = "M"
VERIFIED_CONTRACT_STATUS = "V"
REJECTED_CONTRACT_STATUS = "R"
CONTRACT_STATUSES = (
    (PENDING_CONTRACT_STATUS, "Pending"),
    (ACCEPTED_CONTRACT_STATUS, "Accepted"),
    (MODIFY_CONTRACT_STATUS, "Modify"),
    (VERIFIED_CONTRACT_STATUS, "Verified"),
    (REJECTED_CONTRACT_STATUS, "Rejected"),
)
PHONE_CONTRACT_ACCEPTANCE = "P"
MAIL_CONTRACT_ACCEPTANCE = "M"
DASHBOARD_CONTRACT_ACCEPTANCE = "D"
CONTRACT_ACCEPTANCE_CHANNELS = (
    (PHONE_CONTRACT_ACCEPTANCE, "Phone"),
    (MAIL_CONTRACT_ACCEPTANCE, "Mail"),
    (DASHBOARD_CONTRACT_ACCEPTANCE, "Dashboard"),
)

NEW_INVOICE_NOTIF_TYPE = 'NI'
INVOICE_WITHDRAWN_NOTIF_TYPE = 'IW'
INVOICE_REPAID_NOTIF_TYPE = 'IR'
INVOICE_FUNDED_NOTIF_TYPE = 'IF'
INVOICE_AWAITING_PAYMENT_NOTIF_TYPE = 'IA'
INVOICE_VALIDATED_NOTIF_TYPE = 'IV'
INVOICE_OVERDUE_NOTIF_TYPE = 'IO'
INVOICE_REJECTED_NOTIF_TYPE = 'IX'
AMEND_INVOICE_NOTIF_TYPE = 'MI'
CONTRACT_CONFIRMED_NOTIF_TYPE = 'CC'
MODIFY_CONTRACT_NOTIF_TYPE = 'CM'
NEW_CONTRACT_NOTIF_TYPE = 'NC'
ADMIN_NEW_PROFILE_NOTIF_TYPE = 'NEW_PROFILE'
ADMIN_VALIDATE_BUYER_NOTIF_TYPE = 'VAL_BUYER'
ADMIN_VAL_INVOICE_NOTIF_TYPE = 'VAL_INVOICE'
ADMIN_CONTRACT_DD_NOTIF_TYPE = 'CONTRACT_DD'

ADMIN_NOTIFICATION_TYPES = (
    ADMIN_NEW_PROFILE_NOTIF_TYPE,
    ADMIN_VALIDATE_BUYER_NOTIF_TYPE,
    ADMIN_VAL_INVOICE_NOTIF_TYPE,
    ADMIN_CONTRACT_DD_NOTIF_TYPE,
)

NOTIFICATION_TYPES = (
    (NEW_INVOICE_NOTIF_TYPE, 'New Invoice/PO'),
    (INVOICE_WITHDRAWN_NOTIF_TYPE, 'Invoice/PO Withdrawn'),
    (INVOICE_REPAID_NOTIF_TYPE, 'Invoice/PO Repaid'),
    (INVOICE_FUNDED_NOTIF_TYPE, 'Invoice/PO Funded'),
    (INVOICE_OVERDUE_NOTIF_TYPE, 'Invoice/PO Overdue'),
    (AMEND_INVOICE_NOTIF_TYPE, 'Amend Invoice/PO'),
    (INVOICE_AWAITING_PAYMENT_NOTIF_TYPE, 'Invoice/PO Awaiting Payment'),
    (INVOICE_VALIDATED_NOTIF_TYPE, 'Invoice/PO Validated'),
    (CONTRACT_CONFIRMED_NOTIF_TYPE, 'Contract Confirmed'),
    (MODIFY_CONTRACT_NOTIF_TYPE, 'Modify Contract'),
    (NEW_CONTRACT_NOTIF_TYPE, 'New Contract'),
    (ADMIN_NEW_PROFILE_NOTIF_TYPE, 'New Profile Request'),
    (ADMIN_VALIDATE_BUYER_NOTIF_TYPE, 'Validate Buyer'),
    (ADMIN_VAL_INVOICE_NOTIF_TYPE, 'Validate Invoice'),
    (ADMIN_VAL_INVOICE_NOTIF_TYPE, 'Review Contract DD Docs'),
)

REJECTED_PROFILE_STATUS = "R"
APPROVED_PROFILE_STATUS = "A"
PENDING_PROFILE_STATUS = "P"

PROFILE_REQUEST_STATUSES = (
    (REJECTED_PROFILE_STATUS, "Rejected"),
    (APPROVED_PROFILE_STATUS, "Approved"),
    (PENDING_PROFILE_STATUS, "Pending"),
)

INDIVIDUAL_BANK_ACCOUNT = "individual"
CORPORATE_BANK_ACCOUNT = "corporate"
BANK_ACCOUNT_TYPES = (
    (INDIVIDUAL_BANK_ACCOUNT, INDIVIDUAL_BANK_ACCOUNT.title()),
    (CORPORATE_BANK_ACCOUNT, CORPORATE_BANK_ACCOUNT.title()),
)

DEBIT_TRANSACTION = "D"
CREDIT_TRANSACTION = "C"
TRANSACTION_TYPES = (
    (DEBIT_TRANSACTION, "Debit"),
    (CREDIT_TRANSACTION, "Credit"),
)

VERTO_PAYMENT_GTW = "1"
PAYMENT_GTW = (
    (VERTO_PAYMENT_GTW, "Verto"),
)

BANK_ACCT_REJECTED_STATUS = "R"
BANK_ACCT_APPROVED_STATUS = "A"
BANK_ACCT_PROCESSING_STATUS = "P"

BANK_ACCT_STATUSES = (
    (BANK_ACCT_REJECTED_STATUS, "Rejected"),
    (BANK_ACCT_APPROVED_STATUS, "Approved"),
    (BANK_ACCT_PROCESSING_STATUS, "Processing"),
)

PO_INVOICE_TYPE = "P"
NORMAL_INVOICE_TYPE = "N"
INVOICE_TYPES = (
    (NORMAL_INVOICE_TYPE, "Normal"),
    (PO_INVOICE_TYPE, "Purchase Order"),
)
